# encoding: utf-8
require 'spec_helper'

describe Quandl::Sandbox::Server do
  
  let(:config){ Quandl::Sandbox.configuration }
  let(:server){ Quandl::Sandbox::Server.new }
  
  subject{ server }
  
  Quandl::Sandbox::Server.attributes.each do |name|
    its(name){ should eq config.send(name) } if Quandl::Sandbox.configuration.respond_to?(name)
  end
  
  describe "#uid" do
    subject{ server.uid }
    its(:length){ should eq 12 }
  end
  
  describe "#node_name" do
    subject{ server.node_name }
    it{ should match /#{server.environment}/ }
    it{ should match /sandbox-worker/ }
    it{ should match /#{server.uid}/ }
  end
  
  context "with created server" do
    
    before(:all) do
      @server = Quandl::Sandbox::Server.create
    end
    
    subject{ @server }
    
    its(:exists?){ should be_true }
    its(:launch!){ should be_false }
    its(:instance_id){ should be_present }
    its(:subnet_id){ should eq Quandl::Sandbox.configuration.subnet_id }
    
    describe ".find" do
      it "should find the server" do
        s = Quandl::Sandbox::Server.find(subject.instance_id)
        s.exists?.should be_true
      end
      it "should not find servers outside of the subnet" do
        s = Quandl::Sandbox::Server.find("i-a4002dc5")
        s.should be_nil
      end
    end
    
    describe "#exec" do
      it "should get the hostname" do
        # get internal_ip through exec('hostname')
        internal_ip = subject.exec('hostname')[:stdout].split('-')[1..-1].join('.')
        # compare against private ip address
        subject.private_ip_address.should eq internal_ip
      end
    end

    after(:all) do
      @server.delete rescue nil
    end
    
  end
  
end